
syntax = "proto2";

import "perf_data.proto";

option java_package = "com.google.android.perfprofd";

package android.perfprofd;

message PerfprofdRecord {
  // Symbol info for a shared library without build id.
  message SymbolInfo {
    // A symbol, stretching the given range of the library.
    message Symbol {
      optional string name = 1;
      optional uint64 name_md5_prefix = 2;

      optional uint64 addr = 3;
      optional uint64 size = 4;
    };

    optional string filename = 1;
    optional uint64 filename_md5_prefix = 2;

    optional uint64 min_vaddr = 3;

    repeated Symbol symbols = 4;
  };

  optional int64 id = 1;
  optional quipper.PerfDataProto perf_data = 2;

  // Extra symbol info.
  repeated SymbolInfo symbol_info = 3;

  // Stats inherited from old perf_profile.proto.

  // is device screen on at point when profile is collected?
  optional bool display_on = 5;

  // system load at point when profile is collected; corresponds
  // to first value from /proc/loadavg multiplied by 100 then
  // converted to int32
  optional int32 sys_load_average = 6;

  // At the point when the profile was collected, was a camera active?
  optional bool camera_active = 7;

  // At the point when the profile was collected, was the device still booting?
  optional bool booting = 8;

  // At the point when the profile was collected, was the device plugged into
  // a charger?
  optional bool on_charger = 9;

  // CPU utilization measured prior to profile collection (expressed as
  // 100 minus the idle percentage).
  optional int32 cpu_utilization = 10;
};
